@@ -72,10 +72,14 @@ sub request_base          { $_[0]->env->{REQUEST_BASE} || $_[0]->env->{HTTP_REQU
 sub scheme                {
     my $scheme;
     if (setting('behind_proxy')) {
+        # PSGI specs say that X_FORWARDED_PROTO will
+        # be converted into HTTP_X_FORWARDED_PROTO
+        # but Dancer::Test doesn't use PSGI (for now)
         $scheme = $_[0]->env->{'X_FORWARDED_PROTOCOL'}
                || $_[0]->env->{'HTTP_X_FORWARDED_PROTOCOL'}
                || $_[0]->env->{'HTTP_X_FORWARDED_PROTO'}
                || $_[0]->env->{'HTTP_FORWARDED_PROTO'}
+               || $_[0]->env->{'X_FORWARDED_PROTO'}
                || ""
     }
     return $scheme
