@@ -1,8 +1,4 @@
 package Dancer::Serializer::JSONP;
-our $AUTHORITY = 'cpan:SUKRIA';
-$Dancer::Serializer::JSONP::VERSION = '1.3514_04'; # TRIAL
-$Dancer::Serializer::JSONP::VERSION = '1.351404';
-# ABSTRACT: serializer for handling JSONP data
 
 use strict;
 use warnings;
@@ -22,21 +18,12 @@ sub serialize {
 sub content_type {'application/javascript'}
 
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Serializer::JSONP - serializer for handling JSONP data
 
-=head1 VERSION
-
-version 1.3514_04
-
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -79,16 +66,3 @@ not supported by a browser.
 =head1 AUTHOR
 
 David Zurborg, C<< <zurborg at cpan.org> >>
-
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
